@@ -3,13 +3,15 @@ package DBIx::Class::Validation::Structure;
 use strict;
 use warnings;
 use 5.008_005;
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 use Email::Valid;
 use HTML::TagFilter;
 
 use base qw/DBIx::Class/;
 
+use utf8;
+
 sub validate {
   my $self = shift;
   my @check_columns = @_;
@@ -208,8 +210,8 @@ sub _val_text {
     return (undef, { msg => 'cannot be blank' });
   } elsif ($len && length($value) && (length($value) > $len) ) {
     return (undef, { msg => 'is limited to '.$len.' characters' });
-  } elsif (defined $value && $value !~ /^([\d\w \.\,\-\'\"\!\$\#\%\=\&\:\+\(\)\?\;\n\r\<\>\/\@äÄöÖüÜßéÉáÁíÍ]*)$/) {
-    return (undef, { msg => 'can only use letters, 0-9 and -.,\'\"!&#$?:()=%<>;/@ (do not cut and paste from a Word document, you must Save As text only)' });
+  } elsif (defined $value && $value !~ /^([\d \.\,\-\'\"\!\$\#\%\=\&\:\+\(\)\[\]\?\;\n\r\<\>\/\@\w]*)$/) {
+    return (undef, { msg => 'can only use letters, 0-9 and -.,\'\"!&#$?:()[]=%<>;/@ (do not cut and paste from a Word document, you must Save As text only)' });
   } else {
     if (defined $value) {  # This is to prevent empty strings from returning as the last regex match.
       return ($1);  # $1 is a tricky value. If value is blank $1 will be the last regex match.
@@ -234,8 +236,8 @@ sub _val_password {
     return (undef, { msg => 'cannot be blank' });
   } elsif ($len && length($value) && (length($value) > $len) ) {
     return (undef, { msg => 'is limited to '.$len.' characters' });
-  } elsif ($value && $value !~ /^([\w \.\,\-\'\"\!\$\#\%\=\&\:\+\(\)\{\}\?\;\n\r\<\>\/\@äÄöÖüÜßéÉáÁíÍ]*)$/) {
-    return (undef, { msg => 'can only use letters, 0-9 and -.,\'\"!&#$?:()=%<>;/@ (do not cut and paste from a Word document, you must Save As text only)' });
+  } elsif ($value && $value !~ /^([\w \.\,\-\'\"\!\$\#\%\=\&\:\+\(\)\[\]\{\}\?\;\n\r\<\>\/\@\w]*)$/) {
+    return (undef, { msg => 'can only use letters, 0-9 and -.,\'\"!&#$?:()[]=%<>;/@ (do not cut and paste from a Word document, you must Save As text only)' });
   } else {
     my $tf = new HTML::TagFilter;
     if ($value) {  # This is to prevent empty strings from returning as the folder name.
